@@ -120,7 +120,7 @@ names(.all_aes_values) <- .all_aes_names
         }
 
         res <- slot(param_choices, .plotPointSampleRes)
-        subset.args <- sprintf("resolution=%i", res)
+        subset.args <- sprintf("resolution=%f", res)
         if (priority) {
             if (rescaled) {
                 subset.args <- paste0(subset.args, "*.rescaled")
@@ -531,7 +531,7 @@ plot.data$Y <- tmp;")
     plot_cmds[["ggplot"]] <- "dot.plot <- ggplot(plot.data) +"
     plot_cmds[["tile"]] <-
 "geom_tile(aes(x=X, y=Y, height=2*YWidth, width=2*XWidth, group=interaction(X, Y)),
-    summary.data, color='black', alpha=0, size=0.5) +"
+    summary.data, color='black', alpha=0, linewidth=0.5) +"
 
     # Adding the points to the plot (with/without point selection).
     color_set <- !is.null(plot_data$ColorBy)
@@ -764,7 +764,7 @@ plot.data$jitteredY <- j.out$Y;", groupvar)
 
     if (custom_point_size && discrete_color) {
         sprintf(
-            "guides(colour = guide_legend(override.aes = list(size=%i)), fill = guide_legend(override.aes = list(size=%i))) +",
+            "guides(colour = guide_legend(override.aes = list(size=%f)), fill = guide_legend(override.aes = list(size=%f))) +",
             legend_size, legend_size
         )
     } else {
